The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Title: Bayesian Hierarchical Models for Single-Cell Protein Data
Version: 1.0.1
Description: Bayesian Hierarchical beta-binomial models for modeling cell population to predictors/exposures. This package utilizes 'runjags' to run Gibbs sampling, parallelizing the chains. Options for different covariances/relationship structures between parameters of interest.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: coda, runjags, VGAM, matlib
Depends: rjags
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-02-24 19:34:02 UTC; cjsakitis
Author: Chase Sakitis [aut, cre], Brooke Fridley [aut]
Maintainer: Chase Sakitis <cjsakitis@cmh.edu>
Repository: CRAN
Date/Publication: 2026-02-24 22:30:08 UTC

Bayesian Immune Cell Abundance Model (BICAM)

Description

Bayesian Immune Cell Abundance Model (BICAM)

Usage

BICAM(
  dat,
  M,
  adapt,
  burn,
  it,
  thin = 1,
  ran_eff = 1,
  chains = 4,
  cores = 4,
  v0_mu_logit = 0.01,
  ncov = 1,
  model = "Unstr",
  dis = NULL,
  tree = NULL,
  treelevels = NULL
)

Arguments

dat

data frame with dataset (proper setup displayed in tutorial)

M

number of cell types/parameters of interest

adapt

number of adaptation iterations (for compiling model)

burn

number of burn-in iterations

it

number of sampling iterations (after burn-in)

thin

number of thinning samples

ran_eff

indicate whether to use random subject effect (repeated measurements)

chains

number of chains to run

cores

number of cores

v0_mu_logit

anticipated proportion of cell types/parameters

ncov

number of covariates input into the model

model

covariance model selection

dis

distance matrix for Exp. Decay model

tree

tree-structured covariance matrix for Tree and Scaled Tree models

treelevels

list of matrices for multilevel, tree-structured covariance matrix for TreeLevels model

Value

A list of inputs and results

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.